# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from assisted_service_client.api_client import ApiClient


class BootfilesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def download_boot_files(self, openshift_version, file_type, **kwargs):  # noqa: E501
        """download_boot_files  # noqa: E501

        Downloads files used for booting servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_boot_files(openshift_version, file_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str openshift_version: The corresponding OpenShift version for the boot file. (required)
        :param str file_type: The file type to download. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_boot_files_with_http_info(openshift_version, file_type, **kwargs)  # noqa: E501
        else:
            (data) = self.download_boot_files_with_http_info(openshift_version, file_type, **kwargs)  # noqa: E501
            return data

    def download_boot_files_with_http_info(self, openshift_version, file_type, **kwargs):  # noqa: E501
        """download_boot_files  # noqa: E501

        Downloads files used for booting servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_boot_files_with_http_info(openshift_version, file_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str openshift_version: The corresponding OpenShift version for the boot file. (required)
        :param str file_type: The file type to download. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['openshift_version', 'file_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_boot_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'openshift_version' is set
        if ('openshift_version' not in params or
                params['openshift_version'] is None):
            raise ValueError("Missing the required parameter `openshift_version` when calling `download_boot_files`")  # noqa: E501
        # verify the required parameter 'file_type' is set
        if ('file_type' not in params or
                params['file_type'] is None):
            raise ValueError("Missing the required parameter `file_type` when calling `download_boot_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'openshift_version' in params:
            query_params.append(('openshift_version', params['openshift_version']))  # noqa: E501
        if 'file_type' in params:
            query_params.append(('file_type', params['file_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/boot-files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
